@@ -81,12 +81,12 @@ class Bip44BaseConst:
     COIN_DEPTH          = 2
     # Account depth
     ACCOUNT_DEPTH       = 3
-    # Chain depth
-    CHAIN_DEPTH         = 4
+    # Change depth
+    CHANGE_DEPTH        = 4
     # Address depth
     ADDRESS_INDEX_DEPTH = 5
 
-    # Test ent coin index
+    # Test net coin index
     TEST_NET_COIN_IDX   = 1
 
     # Map test net coins to main net coins
@@ -112,11 +112,30 @@ class Bip44Base(ABC):
 
     def __init__(self, bip32_obj, coin_idx):
         """ Construct class from a Bip32 object and coin type.
+        ValueError is raised if coin is not allowed to derive from current specification.
+        Bip44DepthError is raised if the Bip32 object depth is not valid.
 
         Args:
             bip32_obj (Bip32 object) : Bip32 object
             coin_idx (Bip44Coins)    : coin index, must be a Bip44Coins enum
         """
+
+        # Check if coin is allowed
+        if not self.IsCoinAllowed(coin_idx):
+            raise ValueError("Coin %s cannot derive from %s specification" % (coin_idx, self.SpecName()))
+
+        # If the Bip32 is public-only, the depth shall start from the change level because hardened derivation is
+        # used below it, which is not possible with public keys
+        if bip32_obj.IsPublicOnly():
+            if bip32_obj.Depth() < Bip44BaseConst.CHANGE_DEPTH or \
+               bip32_obj.Depth() > Bip44BaseConst.ADDRESS_INDEX_DEPTH:
+                raise Bip44DepthError("Depth of the public-only Bip32 object (%d) is below change level or beyond address index level" % bip32_obj.Depth())
+        # If the Bip32 object is not public-only, any depth is fine as long as it is not greater than address index level
+        else:
+            if bip32_obj.Depth() > Bip44BaseConst.ADDRESS_INDEX_DEPTH:
+                raise Bip44DepthError("Depth of the Bip32 object (%d) is beyond address index level" % bip32_obj.Depth())
+
+        # Finally, initialize class
         self.m_bip32    = bip32_obj
         self.m_coin_idx = coin_idx
 
@@ -137,9 +156,6 @@ class Bip44Base(ABC):
             Bip object
         """
 
-        if not isinstance(coin_idx, Bip44Coins):
-            raise TypeError("Coin index is not an enumerative of Bip44Coins")
-
         # Check if test net
         if coin_idx in Bip44BaseConst.TESTNET_TO_MAINNET_COINS:
             coin_idx = Bip44BaseConst.TESTNET_TO_MAINNET_COINS[coin_idx]
@@ -162,9 +178,6 @@ class Bip44Base(ABC):
             Bip object
         """
 
-        if not isinstance(coin_idx, Bip44Coins):
-            raise TypeError("Coin index is not an enumerative of Bip44Coins")
-
         # Check if test net
         if coin_idx in Bip44BaseConst.TESTNET_TO_MAINNET_COINS:
             coin_idx = Bip44BaseConst.TESTNET_TO_MAINNET_COINS[coin_idx]
@@ -196,7 +209,7 @@ class Bip44Base(ABC):
             # Get versions
             main_pub_net_ver = self._GetMainNetVersions(self.m_coin_idx)["pub"]
             test_pub_net_ver = self._GetTestNetVersions(self.m_coin_idx)["pub"]
-            # Get extendewd key
+            # Get extended key
             return self.m_bip32.ExtendedPublicKey(main_pub_net_ver, test_pub_net_ver)
         else:
             return self.m_bip32.PublicKeyBytes(key_type == Bip44PubKeyTypes.RAW_COMPR_KEY)
@@ -220,7 +233,7 @@ class Bip44Base(ABC):
             # Get versions
             main_pub_net_ver = self._GetMainNetVersions(self.m_coin_idx)["priv"]
             test_pub_net_ver = self._GetTestNetVersions(self.m_coin_idx)["priv"]
-            # Get extendewd key
+            # Get extended key
             return self.m_bip32.ExtendedPrivateKey(main_pub_net_ver, test_pub_net_ver)
         else:
             return self.m_bip32.PrivateKeyBytes()
@@ -247,6 +260,33 @@ class Bip44Base(ABC):
         else:
             return ""
 
+    def CoinNames(self):
+        """ Get coin names.
+
+        Args:
+            coin_idx (Bip44Coins) : coin index, must be a Bip44Coins enum
+
+        Returns (dict):
+            Coin names (name at key "name", abbreviation at key "abbr")
+        """
+        return self._GetCoinNames(self.m_coin_idx)
+
+    def IsPublicOnly(self):
+        """ Get if it's public-only.
+
+        Returns (bool):
+            True if public-only, false otherwise
+        """
+        return self.m_bip32.IsPublicOnly()
+
+    def IsTestNet(self):
+        """ Return if it's a test net.
+
+        Returns (bool):
+            True if test net, false otherwise
+        """
+        return self.m_bip32.IsTestNet()
+
     def IsMasterLevel(self):
         """ Return if it's a master path.
 
@@ -285,7 +325,7 @@ class Bip44Base(ABC):
         Returns (bool):
             True if chain path, false otherwise
         """
-        return self.m_bip32.Depth() == Bip44BaseConst.CHAIN_DEPTH
+        return self.m_bip32.Depth() == Bip44BaseConst.CHANGE_DEPTH
 
     def IsAddressIndexLevel(self):
         """ Return if it's a address index path.
@@ -335,7 +375,7 @@ class Bip44Base(ABC):
         pass
 
     @abstractmethod
-    def Change(self, chain_idx):
+    def Change(self, change_idx):
         """ Derive a child key from the specified account index and return a new Bip object (e.g. BIP44, BIP49, BIP84).
         It shall call the underlying _ChangeGeneric method with the current object as parameter.
         TypeError is raised if chain type is not a Bip44Changes enum.
@@ -343,7 +383,7 @@ class Bip44Base(ABC):
         Bip32KeyError is raised (by Bip32) if the change results in an invalid key.
 
         Args:
-            chain_idx (Bip44Changes) : chain index, must a Bip44Changes enum
+            change_idx (Bip44Changes) : change index, must a Bip44Changes enum
 
         Returns (Bip object):
             Bip object
@@ -365,6 +405,30 @@ class Bip44Base(ABC):
         """
         pass
 
+    @staticmethod
+    @abstractmethod
+    def SpecName():
+        """ Get specification name
+
+        Returns (str):
+            Specification name
+        """
+        pass
+
+    @staticmethod
+    @abstractmethod
+    def IsCoinAllowed(coin_idx):
+        """ Get if the specified coin is allowed.
+        TypeError is raised if coin_idx is not of Bip44Coins enum.
+
+        Args:
+            coin_idx (Bip44Coins) : coin index, must be a Bip44Coins enum
+
+        Returns (bool):
+            True if allowed, false otherwise
+        """
+        pass
+
     @staticmethod
     @abstractmethod
     def _GetPurpose():
@@ -427,6 +491,19 @@ class Bip44Base(ABC):
         """
         pass
 
+    @staticmethod
+    @abstractmethod
+    def _GetCoinNames(coin_idx):
+        """ Get coin names.
+
+        Args:
+            coin_idx (Bip44Coins) : coin index, must be a Bip44Coins enum
+
+        Returns (dict):
+            Coin names (name at key "name", abbreviation at key "abbr")
+        """
+        pass
+
     @classmethod
     def _PurposeGeneric(cls, bip_obj):
         """ Derive a child key from the purpose and return a new Bip object (e.g. BIP44, BIP49, BIP84).
@@ -486,7 +563,7 @@ class Bip44Base(ABC):
         return cls(bip_obj.m_bip32.ChildKey(Bip32.HardenIndex(acc_idx)), bip_obj.m_coin_idx)
 
     @classmethod
-    def _ChangeGeneric(cls, bip_obj, chain_idx):
+    def _ChangeGeneric(cls, bip_obj, change_idx):
         """ Derive a child key from the specified chain type and return a new Bip object (e.g. BIP44, BIP49, BIP84).
         It shall be called from a child class.
         TypeError is raised if chain type is not a Bip44Changes enum.
@@ -494,19 +571,19 @@ class Bip44Base(ABC):
         Bip32KeyError is raised (by Bip32) if the change results in an invalid key.
 
         Args:
-            bip_obj (BIP object)    : Bip object (e.g. BIP44, BIP49, BIP84)
-            chain_idx (Bip44Changes) : chain index, must a Bip44Changes enum
+            bip_obj (BIP object)      : Bip object (e.g. BIP44, BIP49, BIP84)
+            change_idx (Bip44Changes) : change index, must a Bip44Changes enum
 
         Returns (Bip object):
             Bip object
         """
-        if not isinstance(chain_idx, Bip44Changes):
-            raise TypeError("Chain index is not an enumerative of Bip44Changes")
+        if not isinstance(change_idx, Bip44Changes):
+            raise TypeError("Change index is not an enumerative of Bip44Changes")
 
         if not cls.IsAccountLevel(bip_obj):
-            raise Bip44DepthError("Current depth (%d) is not suitable for deriving chain" % bip_obj.m_bip32.Depth())
+            raise Bip44DepthError("Current depth (%d) is not suitable for deriving change" % bip_obj.m_bip32.Depth())
 
-        return cls(bip_obj.m_bip32.ChildKey(chain_idx), bip_obj.m_coin_idx)
+        return cls(bip_obj.m_bip32.ChildKey(change_idx), bip_obj.m_coin_idx)
 
     @classmethod
     def _AddressIndexGeneric(cls, bip_obj, addr_idx):
