@@ -31,8 +31,10 @@ from .bip84_coin_helper import *
 class Bip84Const:
     """ Class container for BIP44 constants. """
 
+    # Specification name
+    SPEC_NAME = "BIP-0084"
     # Purpose
-    PURPOSE       = Bip32.HardenIndex(84)
+    PURPOSE   = Bip32.HardenIndex(84)
     # Allowed coins
     ALLOWED_COINS = \
         [
@@ -49,20 +51,6 @@ class Bip84Const:
 class Bip84(Bip44Base):
     """ BIP84 class. """
 
-    def __init__(self, bip32_obj, coin_idx):
-        """ Construct class from a Bip32 object and coin type.
-
-        Args:
-            bip32_obj (Bip32 object) : Bip32 object
-            coin_idx (Bip44Coins)    : coin index, must be a Bip44Coins enum
-        """
-
-        # Check if coin is allowed for BIP-0049
-        if not coin_idx in Bip84Const.ALLOWED_COINS:
-            raise ValueError("Only Bitcoin and Litecoin can derive BIP-0084")
-        # Construct parent
-        super().__init__(bip32_obj, coin_idx)
-
     def Purpose(self):
         """ Derive a child key from the purpose and return a new Bip object (e.g. BIP44, BIP49, BIP84).
         It calls the underlying _PurposeGeneric method with the current object as parameter.
@@ -99,7 +87,7 @@ class Bip84(Bip44Base):
         """
         return self._AccountGeneric(self, acc_idx)
 
-    def Change(self, chain_idx):
+    def Change(self, change_idx):
         """ Derive a child key from the specified account index and return a new Bip object (e.g. BIP44, BIP49, BIP84).
         It calls the underlying _ChangeGeneric method with the current object as parameter.
         TypeError is raised if chain type is not a Bip44Changes enum.
@@ -107,12 +95,12 @@ class Bip84(Bip44Base):
         Bip32KeyError is raised (by Bip32) if the change results in an invalid key.
 
         Args:
-            chain_idx (Bip44Changes) : chain index, must a Bip44Changes enum
+            change_idx (Bip44Changes) : change index, must a Bip44Changes enum
 
         Returns (Bip object):
             Bip object
         """
-        return self._ChangeGeneric(self, chain_idx)
+        return self._ChangeGeneric(self, change_idx)
 
     def AddressIndex(self, addr_idx):
         """ Derive a child key from the specified account index and return a new Bip object (e.g. BIP44, BIP49, BIP84).
@@ -128,6 +116,31 @@ class Bip84(Bip44Base):
         """
         return self._AddressIndexGeneric(self, addr_idx)
 
+    @staticmethod
+    def SpecName():
+        """ Get specification name
+
+        Returns (str):
+            Specification name
+        """
+        return Bip84Const.SPEC_NAME
+
+    @staticmethod
+    def IsCoinAllowed(coin_idx):
+        """ Get if the specified coin is allowed.
+        TypeError is raised if coin_idx is not of Bip44Coins enum.
+
+        Args:
+            coin_idx (Bip44Coins) : coin index, must be a Bip44Coins enum
+
+        Returns (bool):
+            True if allowed, false otherwise
+        """
+        if not isinstance(coin_idx, Bip44Coins):
+            raise TypeError("Coin index is not an enumerative of Bip44Coins")
+
+        return coin_idx in Bip84Const.ALLOWED_COINS
+
     @staticmethod
     def _GetPurpose():
         """ Get purpose.
@@ -183,4 +196,16 @@ class Bip84(Bip44Base):
         Returns (dict or None):
             WIF net versions (main net at key "main", test net at key "test"), None if not supported
         """
-        return Bip84Const.COIN_TO_HELPER[coin_idx].GetWifNetVersions()
+        return Bip84Const.COIN_TO_HELPER[coin_idx].GetConfig().WIF_NET_VER
+
+    @staticmethod
+    def _GetCoinNames(coin_idx):
+        """ Get coin names.
+
+        Args:
+            coin_idx (Bip44Coins) : coin index, must be a Bip44Coins enum
+
+        Returns (dict):
+            Coin names (name at key "name", abbreviation at key "abbr")
+        """
+        return Bip84Const.COIN_TO_HELPER[coin_idx].GetConfig().NAMES
